@@ -3,7 +3,7 @@ BEGIN {
   $Catalyst::Authentication::Credential::Twitter::AUTHORITY = 'cpan:JESSESTAY';
 }
 {
-  $Catalyst::Authentication::Credential::Twitter::VERSION = '2.0.0';
+  $Catalyst::Authentication::Credential::Twitter::VERSION = '2.0.1';
 }
 # ABSTRACT:  Twitter authentication for Catalyst
 
@@ -75,9 +75,9 @@ sub authenticate_twitter {
 	my $access_token_secret = $c->user_session->{'access_token_secret'};
 
     # Create a Net::Twitter instance
-    $self->_twitter(Net::Twitter->new({ 
-		'traits'        	=> ['API::REST', 'OAuth'],
-		'consumer_key' 		=> $self->consumer_key, 
+    $self->_twitter(Net::Twitter->new({
+		'traits'        	=> ['API::RESTv1_1', 'OAuth'],
+		'consumer_key' 		=> $self->consumer_key,
         'consumer_secret'	=> $self->consumer_secret,
 	}));
 
@@ -144,14 +144,14 @@ sub authenticate {
     return $user_obj;
 
 }
-    
+
 sub authenticate_twitter_url {
     my ($self, $c) = @_;
 
     # Create a Net::Twitter instance
-    $self->_twitter(Net::Twitter->new( 
-		'traits'        	=> ['API::REST', 'OAuth'],
-		'consumer_key' 		=> $self->consumer_key, 
+    $self->_twitter(Net::Twitter->new(
+		'traits'        	=> ['API::RESTv1_1', 'OAuth'],
+		'consumer_key' 		=> $self->consumer_key,
         'consumer_secret'	=> $self->consumer_secret,
 	));
 
@@ -176,7 +176,7 @@ Catalyst::Authentication::Credential::Twitter - Twitter authentication for Catal
 
 =head1 VERSION
 
-version 2.0.0
+version 2.0.1
 
 =head1 SYNOPSIS
 
